spacepy.toolbox.loadpickle — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »

# spacepy.toolbox.loadpickle

`spacepy.toolbox.` `loadpickle`(fln)

  load a pickle and return content as dictionary

  Parameters: | fln : string filename
  Returns: | out : dict dictionary with content from file

  See also

  `savepickle`

  Examples

  note: If fln is not found, but the same filename with ‘.gz’
    is found, will attempt to open the .gz as a gzipped file.

      >>> d = loadpickle('test.pbin')

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »